# An hello world app in pyramid

This App is a demo of the plaster-yaml package.


Run the app using yaml configuration


```
poetry install
poetry run pserve development.yaml
```


Run the app using json configuration

```
poetry install
poetry run pserve development.json
```


See: https://github.com/mardiros/plaster-yaml
